@@ -7,7 +7,6 @@ from discord.abc import GuildChannel, User
 from discord.ext.commands import Context
 
 from dpymenus import BaseMenu
-from dpymenus.constants import GENERIC_BUTTONS
 from dpymenus.exceptions import ButtonsError, CallbackError
 
 
@@ -16,12 +15,11 @@ class ButtonMenu(BaseMenu):
     Represents a button-based response menu.
 
     :param ctx: A reference to the command context.
-    :param timeout: How long (in seconds) to wait before timing out.
-    :param data: A dictionary containing variables to pass around menu functions.
+    :param data: A dictionary containing dynamic state information.
     """
 
-    def __init__(self, ctx: Context, timeout: int = 300, data: Optional[Dict] = None):
-        super().__init__(ctx, timeout)
+    def __init__(self, ctx: Context, data: Optional[Dict] = None, **kwargs):
+        super().__init__(ctx, **kwargs)
         self.data = data if data else {}
 
     def __repr__(self):
@@ -37,7 +35,7 @@ class ButtonMenu(BaseMenu):
         if await self._start_session() is False:
             return
 
-        self.output = await self.ctx.send(embed=self.page)
+        self.output = await self.destination.send(embed=self.page)
 
         while self.active:
             await self._add_buttons()
@@ -54,7 +52,7 @@ class ButtonMenu(BaseMenu):
             await self.output.add_reaction(button)
 
     async def _get_reaction(self) -> Union[Emoji, str]:
-        """Collects a user reaction and places it into the input attribute. Returns an Emoji or Emoji name."""
+        """Collects a user reaction and places it into the input attribute. Returns a :py:class:`discord.Emoji` or string."""
         try:
             reaction, user = await self.ctx.bot.wait_for('reaction_add', timeout=self.timeout,
                                                          check=self._check_reaction)
@@ -69,7 +67,7 @@ class ButtonMenu(BaseMenu):
 
     async def _cleanup_reactions(self):
         """Removes all reactions from the output message object."""
-        if isinstance(self.ctx.channel, GuildChannel):
+        if isinstance(self.output.channel, GuildChannel):
             await self.output.clear_reactions()
 
     def _check_reaction(self, r: Reaction, u: User) -> bool:
@@ -99,4 +97,3 @@ class ButtonMenu(BaseMenu):
 
         if _cb_count < len(self.pages) - 1:
             raise CallbackError(f'ButtonMenu missing `on_next` callbacks. Expected {len(self.pages) - 1}, found {_cb_count}.')
-
