@@ -12,13 +12,12 @@ class TextMenu(BaseMenu):
 
     :param ctx: A reference to the command context.
     :param delay: How long to wait between deleting user messages (default 0.25).
-    :param timeout: How long (in seconds) to wait before timing out.
-    :param data: A dictionary containing variables to pass around menu functions.
+    :param data: A dictionary containing dynamic state information.
     """
 
-    def __init__(self, ctx: Context, delay: float = 0.250, timeout: int = 300, data: Optional[Dict] = None):
+    def __init__(self, ctx: Context, delay: float = 0.250, data: Optional[Dict] = None, **kwargs):
+        super().__init__(ctx, **kwargs)
         self.delay = delay
-        super().__init__(ctx, timeout)
         self.data = data if data else {}
 
     def __repr__(self):
@@ -33,7 +32,7 @@ class TextMenu(BaseMenu):
         if await self._start_session() is False:
             return
 
-        self.output = await self.ctx.send(embed=self.page)
+        self.output = await self.destination.send(embed=self.page)
 
         _first_iteration = True
         while self.active:
@@ -55,5 +54,5 @@ class TextMenu(BaseMenu):
     # Internal Methods
     async def _cleanup_input(self):
         """Deletes a Discord client user message."""
-        if isinstance(self.ctx.channel, GuildChannel):
+        if isinstance(self.output.channel, GuildChannel):
             await self.input.delete(delay=self.delay)
